EnderecoTomador class

Endereço do tomador.

Constructors

EnderecoTomador({String? xLgr, String? nro, String? xCpl, String? xBairro, String? cMun, String? xMun, String? uf, String? cep})
Construtor.
EnderecoTomador.fromMap(Map<String, dynamic> map)
Cria uma instância a partir de um Map.
factory

Properties

cep String?
CEP.
getter/setter pair
cMun String?
Código do município.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nro String?
Número.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uf String?
UF.
getter/setter pair
xBairro String?
Bairro.
getter/setter pair
xCpl String?
Complemento.
getter/setter pair
xLgr String?
Logradouro.
getter/setter pair
xMun String?
Nome do município.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converte a instância em um Map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited