RegimeTributario class

Regime tributário do prestador.

Constructors

RegimeTributario({String? opSimpNac, String? regEspTrib})
Construtor.
RegimeTributario.fromMap(Map<String, dynamic> map)
Cria uma instância a partir de um Map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
opSimpNac String?
Opção do Simples Nacional (1-Sim, 2-Não).
getter/setter pair
regEspTrib String?
Regime especial de tributação.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converte a instância em um Map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited