Valores class

Valores da NFSe.

Constructors

Valores({ValorServicoPrestado? vServPrest, Tributos? trib})
Construtor.
Valores.fromMap(Map<String, dynamic> map)
Cria uma instância a partir de um Map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trib ↔ Tributos?
Tributos.
getter/setter pair
vServPrest ↔ ValorServicoPrestado?
Valor do serviço prestado.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converte a instância em um Map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited