DanfePrinter class

Implemented types

Constructors

DanfePrinter(PaperSize paperSize)
Construtor da classe DanfePrinter.

Properties

fontName String?
Gera o buffer de dados para impressão do DANFE em formato ESC/POS.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paperSize → PaperSize
Define o tamanho do papel utilizado para a impressão (58mm ou 80mm).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bufferDanfe(Danfe? danfe, {bool mostrarMoeda = true}) Future<List<int>>
Gera um buffer de comandos ESC/POS para impressão do DANFE em uma impressora térmica.
override
normativeJsonDanfe(Danfe? danfe, {bool mostrarMoeda = true, String customFont = 'RobotoMonoRegular'}) String
Gera uma representação normativa em formato JSON do DANFE.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited