DanfePaperSize enum

Enumeração para definir o tamanho do papel da impressão.

Inheritance
Available extensions

Values

mm58 → const DanfePaperSize

Papel de 58mm (largura de 384 pixels).

mm80 → const DanfePaperSize

Papel de 80mm (largura de 576 pixels).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
maxWidth double

Available on DanfePaperSize, provided by the DanfePaperSizeExtension extension

Retorna a largura máxima do papel em pixels.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DanfePaperSize>
A constant List of the values in this enum, in order of their declaration.