NfseParser class

A classe NfseParser fornece métodos utilitários para processar documentos XML de NFSe (Nota Fiscal de Serviços Eletrônica) Nacional em objetos Nfse.

Essa classe utiliza a biblioteca xml para processar o XML e converte os dados em instâncias de Nfse.

A classe é implementada com um construtor privado para garantir que não possa ser instanciada diretamente, sendo usada apenas para acesso aos métodos estáticos.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractBasicInfo(String xmlString) Map<String, String?>
Extrai informações resumidas da NFSe de forma rápida.
isNfseNacional(String xml) bool
Verifica se um XML é uma NFSe Nacional sem fazer o parse completo.
readFromString(String xml) Nfse?
Método público para converter um XML em um objeto Nfse.