LocalPrestacao class
Local da prestação do serviço.
Constructors
- LocalPrestacao({String? cLocPrestacao})
- Construtor.
-
LocalPrestacao.fromMap(Map<
String, dynamic> map) -
Cria uma instância a partir de um Map.
factory
Properties
- cLocPrestacao ↔ String?
-
Código do local de prestação.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converte a instância em um Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited