TotalTributo class
Total de tributos.
Constructors
- TotalTributo({String? indTotTrib, String? vTotTrib})
- Construtor.
-
TotalTributo.fromMap(Map<
String, dynamic> mapTrib) -
Cria uma instância a partir de um Map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indTotTrib ↔ String?
-
Indicador de total de tributos (0-Não informado, 1-Informado).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vTotTrib ↔ String?
-
Valor total aproximado dos tributos.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converte a instância em um Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited