TributoIbsCbs class
Um dos três tributos do grupo <gIBSCBS> de um item: <gIBSUF>,
<gIBSMun> ou <gCBS>.
Os três têm exatamente a mesma forma — alíquota, redução e valor — mudando
apenas o sufixo das tags (pIBSUF/vIBSUF, pIBSMun/vIBSMun,
pCBS/vCBS). Por isso uma única classe atende aos três, parametrizada
pelo sufixo em TributoIbsCbs.fromMap.
Constructors
- TributoIbsCbs({String? aliquota, ReducaoAliquota? reducao, String? valor, String? valorDiferido, String? valorDevolvido, String? creditoPresumido})
-
Construtor da classe
TributoIbsCbs. -
TributoIbsCbs.fromMap(Map<
String, dynamic> map, {required String sufixo}) -
Cria uma instância a partir de
<gIBSUF>,<gIBSMun>ou<gCBS>.factory
Properties
- aliquota ↔ String?
-
Alíquota do tributo (
pIBSUF,pIBSMunoupCBS).getter/setter pair - creditoPresumido ↔ String?
-
Crédito presumido (
gCredPres).getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- reducao ↔ ReducaoAliquota?
-
Redução de alíquota, quando houver (
gRed).getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valor ↔ String?
-
Valor do tributo (
vIBSUF,vIBSMunouvCBS).getter/setter pair - valorDevolvido ↔ String?
-
Valor devolvido ao contribuinte (
gDevTrib).getter/setter pair - valorDiferido ↔ String?
-
Valor diferido (
gDif).getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converte a instância atual em uma string JSON.
-
toMap(
) → Map< String, dynamic> -
Converte a instância atual em um mapa (
Map<String, dynamic>). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited