NfsePrinter class
Constructors
- NfsePrinter(PaperSize paperSize)
- Construtor da classe NfsePrinter.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paperSize → PaperSize
-
Define o tamanho do papel utilizado para a impressão (58mm ou 80mm).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bufferNfse(
Nfse? nfse, {bool mostrarMoeda = true}) → Future< List< int> > - Gera o buffer de dados para impressão da NFSe em formato ESC/POS.
-
normativeJsonNfse(
Nfse? nfse, {bool mostrarMoeda = true}) → String - Gera o JSON normativo para impressão da NFSe.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited